@@ -24,8 +24,8 @@
 ;; Maintainer: Jeremy Baxter <jeremy@baxters.nz>
 ;; Author: nyxkrage
 ;; Original-Author: film42
-;; Package-Version: 20250910.2247
-;; Package-Revision: 09b9b785014e
+;; Package-Version: 20260128.702
+;; Package-Revision: 7cd71f948656
 ;; Package-Requires: ((emacs "27.1"))
 ;; URL: https://github.com/catppuccin/emacs
 
@@ -1243,10 +1243,6 @@ FLAVOR defaults to the value of `catppuccin-flavor'."
            :background ,ctp-mantle)
          (centaur-tabs-selected-modified :foreground ,ctp-red
            :background ,ctp-current)
-         (centaur-tabs-close-unselected :foreground ,ctp-subtext0
-           :background ,ctp-mantle)
-         (centaur-tabs-close-selected :foreground ,ctp-text
-           :background ,ctp-current)
          (centaur-tabs-name-mouse-face :foreground ,ctp-text
            :background ,ctp-surface1)
          (centaur-tabs-close-mouse-face :foreground ,ctp-red
